/*
 * Copyright 2019-2020 Ernst Jan Plugge <rmc@dds.nl>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.smouldering_durtles.wk.views;

import android.content.Context;
import android.util.AttributeSet;
import android.view.View;

import com.smouldering_durtles.wk.R;
import com.smouldering_durtles.wk.util.ThemeUtil;

import static com.smouldering_durtles.wk.util.ObjectSupport.safe;

/**
 * A custom view that shows a thin horizontal bar as a divider.
 */
public final class DividerView extends View {
    /**
     * The constructor.
     *
     * @param context Android context
     */
    public DividerView(final Context context) {
        super(context);
        init();
    }

    /**
     * The constructor.
     *
     * @param context Android context
     * @param attrs attribute set
     */
    public DividerView(final Context context, final AttributeSet attrs) {
        super(context, attrs);
        init();
    }

    /**
     * Initialize the view.
     */
    private void init() {
        safe(() -> setBackgroundColor(ThemeUtil.getColor(R.attr.colorDivider)));
    }
}
